@@ -12,10 +12,8 @@ sub POE::Kernel::ASSERT_DEFAULT () { 1 }
 sub POE::Kernel::CATCH_EXCEPTIONS () { 0 }
 
 BEGIN {
-  package POE::Kernel;
-{
-  $POE::Kernel::VERSION = '1.354';
-}
+  package
+  POE::Kernel;
   use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
 }
 
